@@ -22,7 +22,7 @@ def is_mistake(token):
                         True
                         for m in token.senses
                         if "pos" in m
-                        and (m["pos"] == "NOPOS" or m["pos"] == "NON_WORD")
+                        and (m["pos"] == "NO_POS" or m["pos"] == "NON_WORD")
                     ]
                 )
                 > 0
