@@ -1,14 +1,14 @@
 # coding: utf-8
-from typing import List, NewType, Tuple
 from functools import lru_cache
+from typing import List, NewType, Tuple
 
+from ..tokenizers.chunktokenizer import ChunkTokenizer
+from ..tokenizers.paragraphtokenizer import paragraph_tokenizer
+from ..tokenizers.sentencetokenizer import sentence_tokenizer
 from ..tokenizers.token import Token
 from ..tokenizers.wordtokenizer import WordTokenizer
-from ..tokenizers.chunktokenizer import ChunkTokenizer
-from ..tokenizers.sentencetokenizer import sentence_tokenizer
-from ..tokenizers.paragraphtokenizer import paragraph_tokenizer
 
-PyboToken = NewType("PyboToken", Token)
+BoToken = NewType("BoToken", Token)
 
 
 def space_tok(text: str) -> List[str]:
@@ -18,23 +18,19 @@ def space_tok(text: str) -> List[str]:
     return text.split(" ")
 
 
-def word_tok(text: str, profile, modifs=None, mode="internal") -> List[PyboToken]:
-    tok = get_wordtokenizer(profile, modifs, mode)
+def word_tok(text: str, config=None) -> List[BoToken]:
+    tok = get_wordtokenizer(config=config)
     return tok.tokenize(text)
 
 
-def sentence_tok(
-    text: str, profile, modifs=None, mode="internal"
-) -> List[Tuple[int, List[PyboToken]]]:
-    tok = get_wordtokenizer(profile, modifs, mode)
+def sentence_tok(text: str, config=None) -> List[Tuple[int, List[BoToken]]]:
+    tok = get_wordtokenizer(config=config)
     tokens = tok.tokenize(text)
     return sentence_tokenizer(tokens)
 
 
-def paragraph_tok(
-    text: str, profile, modifs=None, mode="internal"
-) -> List[Tuple[int, List[PyboToken]]]:
-    tok = get_wordtokenizer(profile, modifs, mode)
+def paragraph_tok(text: str, config=None) -> List[Tuple[int, List[BoToken]]]:
+    tok = get_wordtokenizer(config=config)
     tokens = tok.tokenize(text)
     return paragraph_tokenizer(tokens)
 
@@ -42,8 +38,8 @@ def paragraph_tok(
 @lru_cache(
     maxsize=None
 )  # <--- make sure that the trie is only built once then kept in memory
-def get_wordtokenizer(profile, modifs, mode):
-    return WordTokenizer(profile, tok_modifs=modifs, tok_mode=mode)
+def get_wordtokenizer(config=None):
+    return WordTokenizer(config=config)
 
 
 def chunk_tok(text: str) -> List[str]:
